==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/gplivemodel/src/EllipticityThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-07
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef ELLIPTICITYTHREAD_H
#define ELLIPTICITYTHREAD_H

#include "Seismic1DThread.h"

class EllipticityThread : public Seismic1DThread
{
public:
  EllipticityThread(QObject * parent=nullptr);
  EllipticityThread(const EllipticityThread& o);
  ~EllipticityThread();

  virtual ResultsThread * clone() const {return new EllipticityThread(*this);}

  virtual void initResultsGraphs(GraphicSheet * sheet);
  virtual void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  virtual bool setParameters(int& argc, char ** argv);
private:
  virtual void run(GeophysicalModel * m);

  int _nRayleigh;
  bool _abs;
  bool _angleDeg;
  bool _angleRad;
  bool _oneMode;
};

#endif // ELLIPTICITYTHREAD_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/gplivemodel/src/EllipticityThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-11-07
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef ELLIPTICITYTHREAD_H
#define ELLIPTICITYTHREAD_H

#include "Seismic1DThread.h"

class EllipticityThread : public Seismic1DThread
{
public:
  EllipticityThread(QObject * parent=nullptr);
  EllipticityThread(const EllipticityThread& o);
  ~EllipticityThread();

  ResultsThread * clone() const {return new EllipticityThread(*this);}

  void initResultsGraphs(GraphicSheet * sheet);
  void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  bool setParameters(int& argc, char ** argv);
private:
  virtual void run(GeophysicalModel * m);

  int _nRayleigh;
  bool _abs;
  bool _angleDeg;
  bool _angleRad;
  bool _oneMode;
  double _precision;
};

#endif // ELLIPTICITYTHREAD_H
